@@ -74,6 +74,7 @@
 #' @param data A \code{data.frame} to use to obtain information about the
 #'   predictors (e.g. factor levels). If missing, then
 #'   \code{\link{recover_data}} is used to attempt to reconstruct the data.
+#'   See the note with \code{\link{recover_data}} for an important precaution.
 #' @param df Numeric value. This is equivalent to specifying
 #'   \code{options(df = df)}. See \code{\link{update.emmGrid}}.
 #' @param type Character value. If provided, this is saved as the
@@ -131,7 +132,7 @@
 #' Care must be taken when covariate values depend on one another. For example,
 #' when a polynomial model was fitted using predictors \code{x}, \code{x2}
 #' (equal to \code{x^2}), and \code{x3} (equal to \code{x^3}), the reference 
-#' grid will by by default set \code{x2} and \code{x3} to their means, which is
+#' grid will by default set \code{x2} and \code{x3} to their means, which is
 #' inconsistent. The user should instead use the \code{at} argument to set these
 #' to the square and cube of \code{mean(x)}. Better yet, fit the model using
 #' a formula involving \code{poly(x, 3)} or \code{I(x^2)} and \code{I(x^3)}; then
@@ -139,6 +140,16 @@
 #' and the model matrix will have the correct corresponding quadratic and cubic
 #' terms.
 #' 
+#' @section Matrix covariates:
+#' Support for covariates that appear in the dataset as matrices is very limited.
+#' If the matrix has but one column, it is treated like an ordinary covariate.
+#' Otherwise, with more than one column, each column is reduced to a single
+#' reference value -- the result of applying \code{cov.reduce} to each column 
+#' (averaged together 
+#' if that produces more than one value); you may not specify values
+#' in \code{at}; and they are not treated as variables in the reference grid,
+#' except for purposes of obtaining predictions.
+#' 
 #' @section Recovering or overriding model information:
 #' Ability to support a particular class of \code{object} depends on the
 #' existence of \code{recover_data} and \code{emm_basis} methods -- see
@@ -174,12 +185,13 @@
 #' each name should be the name of a single factor in the grid, and its entry a
 #' character vector of the name(s) of its grouping factor(s). \code{nested} may
 #' also be a character value of the form \code{"factor1 \%in\%
-#' (factor2*factor3)"}. If there is more than one such specification, they may
+#' (factor2*factor3)"} (the parentheses are optional). If there is more than one
+#' such specification, they may
 #' be appended separated by commas, or as separate elements of a character
 #' vector. For example, these specifications are equivalent: \code{nesting =
 #' list(state = "country", city = c("state", "country")}, \code{nesting = "state
 #' \%in\% country, city \%in\% (state*country)"}, and \code{nesting = c("state
-#' \%in\% country)", "city \%in\% (state*country)")}.
+#' \%in\% country", "city \%in\% state*country")}.
 #' 
 #' In certain unusual cases, a covariate (rather than a factor) may be nested.
 #' Support for such situations is limited to the extent that only covariate
@@ -354,6 +366,8 @@ ref_grid <- function(object, at, cov.reduce = mean, mult.names, mult.levs,
     
     for (nm in attr(data, "predictors")) {
         x = data[[nm]]
+        if (is.matrix(x) && ncol(x) == 1)   # treat 1-column matrices as covariates
+            x = as.numeric(x)
         
         # Save the original levels of factors, no matter what
         if (is.factor(x) && !(nm %in% coerced$covariates))
@@ -394,8 +408,11 @@ ref_grid <- function(object, at, cov.reduce = mean, mult.names, mult.levs,
     grid = do.call(expand.grid, ref.levels)
     
     # add any matrices
-    for (nm in names(matlevs))
-        grid[[nm]] = matrix(rep(matlevs[[nm]], each=nrow(grid)), nrow=nrow(grid))
+    for (nm in names(matlevs)) {
+        tmp = matrix(rep(matlevs[[nm]], each=nrow(grid)), nrow=nrow(grid))
+        dimnames(tmp) = list(NULL, names(matlevs[[nm]]))
+        grid[[nm]] = tmp
+    }
 
     # resolve any covariate formulas
     for (xnm in names(dep.x)) {
